# Contributing

Thank you for your interest in our libraries!

## Issues

We welcome bug reports and feature requests for the API implementations and their provisioning.  These should be submitted as Issues on GitHub:

- [Sign up][join] for GitHub if you haven't already done so.
- Check whether someone has already submitted a similar Issues.
- If necessary, submit a new Issue.

## Submitting changes

You can submit changes through a GitHub pull request as follows:

* Fork the repository.
* Make and commit changes.
  - Please ensure that contact information is available with the commit data.
* Push your changes to a topic branch in your fork.
* Sign the ICLA if you haven't already done so (see below).
* Submit a pull request.

### Contributor Licence Agreement

We desire that contributors of pull requests have signed, and submitted via email, an [Individual Contributor Licence Agreement][ICLA] (ICLA) (PDF version [here][ICLA-pdf]), which is based on the [Apache ICLA][Apache-ICLA].

The purpose of this agreement is to clearly define the terms under which intellectual property has been contributed to the BBC and thereby allow us to defend the project should there be a legal dispute regarding the software at some future time.

If you haven't signed and emailed the agreement yet then the project owners will contact you using the contact info with the pull request.

  * We may in the future use a tool that allows you to sign online through your GitHub id and automatically checks this when you submit a pull request.